@@ -105,6 +105,7 @@ def render_template(template, config):
                 "key '%s' from template '%s' does not exist in metadata file."
                 % (e.key, template))
         except Exception as e:
+            logger.error("%s", e)
             raise exc.ConfigException(
                 "could not render moustache template %s" % template)
 
@@ -134,7 +135,7 @@ def render_executable(path, config):
 
 def template_paths(root):
     res = []
-    for cur_root, subdirs, files in os.walk(root):
+    for cur_root, _subdirs, files in os.walk(root):
         for f in files:
             inout = (os.path.join(cur_root, f), os.path.join(
                 strip_prefix(root, cur_root), f))
@@ -180,7 +181,7 @@ def parse_opts(argv):
                         default=[])
     parser.add_argument('--fallback-metadata', metavar='FALLBACK_METADATA',
                         nargs='*', help='Files to search when OS_CONFIG_FILES'
-                        'is empty. (default: %(default)s)',
+                        ' is empty. (default: %(default)s)',
                         default=['/var/cache/heat-cfntools/last_metadata',
                                  '/var/lib/heat-cfntools/cfn-init-data',
                                  '/var/lib/cloud/data/cfn-init-data'])
@@ -216,6 +217,16 @@ def parse_opts(argv):
     return opts
 
 
+def load_list_from_json(json_file):
+    json_obj = []
+    if os.path.exists(json_file):
+        with open(json_file) as ocf:
+            json_obj = json.loads(ocf.read())
+    if not isinstance(json_obj, list):
+        raise ValueError("No list defined in json file: %s" % json_file)
+    return json_obj
+
+
 def main(argv=sys.argv):
     opts = parse_opts(argv)
     if opts.print_templates:
@@ -226,8 +237,7 @@ def main(argv=sys.argv):
         if 'OS_CONFIG_FILES' in os.environ:
             opts.metadata = os.environ['OS_CONFIG_FILES'].split(':')
         else:
-            with open(opts.os_config_files) as ocf:
-                opts.metadata = json.loads(ocf.read())
+            opts.metadata = load_list_from_json(opts.os_config_files)
 
     try:
         if opts.templates is None:
@@ -262,3 +272,6 @@ logger.setLevel(logging.INFO)
 add_handler(logger, logging.StreamHandler())
 if os.geteuid() == 0:
     add_handler(logger, logging.FileHandler('/var/log/os-apply-config.log'))
+
+if __name__ == '__main__':
+    sys.exit(main(sys.argv))
